@@ -43,7 +43,7 @@ sub _build_regex { qr{^ \s* pool}x }
 
 =head2 generate
 
-See L<Net::ISC::DHCPd::Config::Role::generate()>.
+See L<Net::ISC::DHCPd::Config::Role/generate>.
 
 =cut
 
